@@ -20,7 +20,7 @@ from typing_extensions import (
     Unpack,
 )
 import uuid
-from urllib.parse import urlsplit, urlunsplit
+from urllib.parse import urlsplit, urlunsplit, parse_qs
 
 # breaking circular dependency
 import stripe  # noqa: IMP101
@@ -556,6 +556,35 @@ class _APIRequestor(object):
             url,
         )
 
+        params = params or {}
+        if params and (method == "get" or method == "delete"):
+            # if we're sending params in the querystring, then we have to make sure we're not
+            # duplicating anything we got back from the server already (like in a list iterator)
+            # so, we parse the querystring the server sends back so we can merge with what we (or the user) are trying to send
+            existing_params = {}
+            for k, v in parse_qs(urlsplit(url).query).items():
+                # note: server sends back "expand[]" but users supply "expand", so we strip the brackets from the key name
+                if k.endswith("[]"):
+                    existing_params[k[:-2]] = v
+                else:
+                    # all querystrings are pulled out as lists.
+                    # We want to keep the querystrings that actually are lists, but flatten the ones that are single values
+                    existing_params[k] = v[0] if len(v) == 1 else v
+
+            # if a user is expanding something that wasn't expanded before, add (and deduplicate) it
+            # this could theoretically work for other lists that we want to merge too, but that doesn't seem to be a use case
+            # it never would have worked before, so I think we can start with `expand` and go from there
+            if "expand" in existing_params and "expand" in params:
+                params["expand"] = list(  # type:ignore - this is a dict
+                    set([*existing_params["expand"], *params["expand"]])
+                )
+
+            params = {
+                **existing_params,
+                # user_supplied params take precedence over server params
+                **params,
+            }
+
         encoded_params = urlencode(list(_api_encode(params or {}, api_mode)))
 
         # Don't use strict form encoding by changing the square bracket control
@@ -586,13 +615,13 @@ class _APIRequestor(object):
 
         if method == "get" or method == "delete":
             if params:
-                query = encoded_params
-                scheme, netloc, path, base_query, fragment = urlsplit(abs_url)
+                # if we're sending query params, we've already merged the incoming ones with the server's "url"
+                # so we can overwrite the whole thing
+                scheme, netloc, path, _, fragment = urlsplit(abs_url)
 
-                if base_query:
-                    query = "%s&%s" % (base_query, query)
-
-                abs_url = urlunsplit((scheme, netloc, path, query, fragment))
+                abs_url = urlunsplit(
+                    (scheme, netloc, path, encoded_params, fragment)
+                )
             post_data = None
         elif method == "post":
             if (
