@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
 import stripe
@@ -19,25 +17,27 @@ class TestCapability(object):
             capability_dict, stripe.api_key
         )
 
-    def test_has_instance_url(self, request_mock):
+    def test_has_instance_url(self):
         resource = self.construct_resource()
         assert (
             resource.instance_url()
             == "/v1/accounts/acct_123/capabilities/%s" % TEST_RESOURCE_ID
         )
 
-    def test_is_not_modifiable(self, request_mock):
+    def test_is_not_modifiable(self):
         with pytest.raises(NotImplementedError):
             stripe.Capability.modify(TEST_RESOURCE_ID, requested=True)
 
-    def test_is_not_retrievable(self, request_mock):
+    def test_is_not_retrievable(self):
         with pytest.raises(NotImplementedError):
             stripe.Capability.retrieve(TEST_RESOURCE_ID)
 
-    def test_is_saveable(self, request_mock):
+    def test_is_saveable(self, http_client_mock):
         resource = self.construct_resource()
         resource.requested = True
         resource.save()
-        request_mock.assert_requested(
-            "post", "/v1/accounts/acct_123/capabilities/%s" % TEST_RESOURCE_ID
+        http_client_mock.assert_requested(
+            "post",
+            path="/v1/accounts/acct_123/capabilities/%s" % TEST_RESOURCE_ID,
+            post_data="requested=True",
         )
